/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.yarn.server.resourcemanager.webapp.dao;

import java.util.ArrayList;
import java.util.Collection;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "nodes")
@XmlAccessorType(XmlAccessType.FIELD)
public class NodesInfo {

  protected ArrayList<NodeInfo> node = new ArrayList<NodeInfo>();

  public NodesInfo() {
  } // JAXB needs this

  public void add(NodeInfo nodeinfo) {
    node.add(nodeinfo);
  }

  public ArrayList<NodeInfo> getNodes() {
    return node;
  }

  public void addAll(ArrayList<NodeInfo> nodesInfo) {
    node.addAll(nodesInfo);
  }

  public void addAll(Collection<NodeInfo> nodesInfo) {
    node.addAll(nodesInfo);
  }
}
